@@ -70,20 +70,3 @@ def format_property_value(name, label, value):
         return intcomma(value)
     else:
         return value
-
-
-def format_unknown_property_value(name, label, value):
-    value = format_property_value(name, label, value)
-
-    # Edges properties don't have an explicit value type, so we have to infer
-    # for dates format
-    try:
-        value = convert_datetime(value)
-        value = django_date(value, settings.DATETIME_FORMAT)
-    except (TypeError, ValueError):
-        try:
-            value = convert_date(value)
-            value = django_date(value, settings.DATE_FORMAT)
-        except (TypeError, ValueError):
-            pass
-    return value
