@@ -1,8 +1,9 @@
 import json
+
 import rows
 from django.core.management.base import BaseCommand
 
-from urlid.models import ElementConfig
+from urlid_graph.models import ElementConfig
 
 
 class Command(BaseCommand):
@@ -14,9 +15,11 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         writer = rows.utils.CsvLazyDictWriter(options["output_filename"])
         for element in ElementConfig.objects.all().iterator():
-            writer.writerow({
-                key: value if key != "data" else json.dumps(value)
-                for key, value in element.__dict__.items()
-                if key != "_state"
-            })
+            writer.writerow(
+                {
+                    key: value if key != "data" else json.dumps(value)
+                    for key, value in element.__dict__.items()
+                    if key != "_state"
+                }
+            )
         writer.close()
