@@ -41,10 +41,7 @@ class Command(BaseCommand):
             for model_name, Model in app_models.items()
         }
         if file_types is all or "object" in file_types:
-            filenames = [
-                str(filename.absolute())
-                for filename in path.glob("*object*.csv*")
-            ]
+            filenames = [str(filename.absolute()) for filename in path.glob("*object*.csv*")]
             oks = []
             for filename in filenames:
                 model = filename.split("object")[1].split(".csv")[0].replace("-", "").replace("_", "")
