@@ -97,7 +97,11 @@ class SavedGraphViewSet(GraphDbMixin, viewsets.ModelViewSet):
 class SavedGraphDetails(GraphDbMixin, APIView):
     def get(self, request, *args, **kwargs):
         graph_pk = kwargs.pop("pk")
-        edges_ids = get_object_or_404(SavedGraph, user=request.user, pk=graph_pk,).edges
+        edges_ids = get_object_or_404(
+            SavedGraph,
+            user=request.user,
+            pk=graph_pk,
+        ).edges
 
         nodes, edges = self.graph.get_by_many_edges(edges_ids)
         return Response(self.serialize_graph(nodes, edges))
@@ -203,20 +207,18 @@ class SearchOnGraphEndpoint(APIView):
         return self.serializer_class
 
     def get(self, *args, **kwargs):
-        data = []
-
         term = self.get_search_term()
-        if term:
-            search_result = ObjectRepository.objects.search_many_entities(term)
-            unique_result = []
-            added_uuids = set()
-            for item in search_result:
-                if item.uuid not in added_uuids:
-                    unique_result.append(item)
-                    added_uuids.add(item.uuid)
-            data = self.get_serializer_class()(unique_result, many=True).data
+        if not term:
+            return Response([])
 
-        return Response(data)
+        search_result = ObjectRepository.objects.search_many_entities(term)
+        unique_result = []
+        added_uuids = set()
+        for item in search_result:
+            if item.uuid not in added_uuids:
+                unique_result.append(item)
+                added_uuids.add(item.uuid)
+        return Response(self.get_serializer_class()(unique_result, many=True).data)
 
 
 class ShortestPathEndpoint(GraphDbMixin, APIView):
@@ -226,7 +228,6 @@ class ShortestPathEndpoint(GraphDbMixin, APIView):
 
 
 class DatasetFilter(APIView):
-
     def get_model(self, slug):
         dataset_models = DatasetModel.subclasses()
         if slug not in dataset_models:
